@@ -1,5 +1,5 @@
 package Sim::OPT::Report;
-# Copyright (C) 2008-2022 by Gian Luca Brunetti and Politecnico di Milano.
+# Copyright (C) 2008-2023 by Gian Luca Brunetti and Politecnico di Milano.
 # This is the module Sim::OPT::Retrieve of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
@@ -38,7 +38,7 @@ no warnings;
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.093';
+$VERSION = '0.095';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -179,10 +179,10 @@ sub newretrieve
   my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } );
 
   my $shortresfile = $resfile;
-  $shortresfile =~ s/$thisto\/tmp\///; #say $tee "IN RETRIEVE: \$shortresfile: $shortresfile, \$resfile: $resfile, \$to: $to, \$thisto: $thisto, \$cleanto: $cleanto";
+  $shortresfile =~ s/$thisto\/cfg\///; #say $tee "IN RETRIEVE: \$shortresfile: $shortresfile, \$resfile: $resfile, \$to: $to, \$thisto: $thisto, \$cleanto: $cleanto";
 
   my $shortflfile = $flfile;
-  $shortflfile =~ s/$thisto\/tmp\///; #say $tee "IN RETRIEVE: \$shortflfile: $shortflfile, \$flfile: $flfile";
+  $shortflfile =~ s/$thisto\/cfg\///; #say $tee "IN RETRIEVE: \$shortflfile: $shortflfile, \$flfile: $flfile";
 
   #say $tee "RELAUNCHED IN RETRIEVE WITH INST " . dump( %inst );
 
@@ -200,7 +200,7 @@ sub newretrieve
 
         my $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<YYY
+res -file ../cfg/$shortresfile -mode script<<YYY
 
 3
 $retrdata[0]
@@ -250,7 +250,7 @@ YYY
         {
           my $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<ZZZ
+res -file ../cfg/$shortresfile -mode script<<ZZZ
 
 3
 $retrdata[0]
@@ -302,7 +302,7 @@ ZZZ
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<TTT
+res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -331,7 +331,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<TTT
+res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -379,7 +379,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<TTT
+res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -416,7 +416,7 @@ TTT
         elsif ( $themereport eq "radabs" )
         {
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<TTT
+res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -456,7 +456,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<TTT
+res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -494,7 +494,7 @@ TTT
         {
           $printthis =
 "cd $thisto/cfg
-res -file ../tmp/$shortresfile -mode script<<TTT
+res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
@@ -531,7 +531,7 @@ TTT
         elsif ( $themereport eq "restemp" )
         {
           $printthis =
-"res -file ../tmp/$shortresfile -mode script<<TTT
+"res -file ../cfg/$shortresfile -mode script<<TTT
 
 3
 $retrdata[0]
